/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;

/* section: NIM_merge_TYPES */
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA {
NI a;
NI b;
};
typedef NimStringDesc* tyArray__Re75IspeoxXy2oCZHwcRrA[2];
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU16 tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw;
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU8 tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NimStringDesc* tyArray__MsV5BSbGWsT9bkb3LKumkBA[41];
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, differs__cUWYbX789ccOdpBttqaEifQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* newName);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, sourceLine__b49bYNvmBdG6RP9cHaZGFhvQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q i);
N_LIB_PRIVATE N_NIMCALL(NI, identLen__cr8f4oiC7y4wZkhdloxc7w)(NimStringDesc* line, NI start);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, differ__fOl7C7KzPONPqjNV4s3alQ)(NimStringDesc* line, NI a, NI b, NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, substrEq__rlI4fq2VQx4GgCkgwctENA)(NimStringDesc* s, NI pos, NI last, NimStringDesc* substr);
static N_INLINE(NimStringDesc*, X5BX5D___FPvLvuwqfYMFkcbGfPM8QQsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x);
N_NIMCALL(NimStringDesc*, mnewString)(NI len);
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___BokNSDrKN1xmV1nA01G9brAsystem)(NI a, NI b);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, beautifyName__9a3XujgxAEMrMsWlLydkJvg)(NimStringDesc* s, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, allCharsInSet__dubrHoRt3C9a0HlJjsxM5ig)(NimStringDesc* s, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw theSet);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqtilde___IUBpCwAnZj8k6Q9b3zNUjzg)(NimStringDesc* s, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringDesc* s, NimStringDesc* prefix);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToUpperAsciiChar)(NIM_CHAR c);
static N_INLINE(NIM_BOOL, contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
static N_INLINE(NI, find__31wM5Ui9c8jnrQ5QD4oPxOQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToLowerAsciiChar)(NIM_CHAR c);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_2, "\'$2\' should be: \'$1\'", 20);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_4, "/home/runner/work/nightlies/nightlies/nim/compiler/linter.nim", 61);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NvI37FoCN5uTD3k9bAqbGMA_3 = {((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_4),
((NI) 128),
((NI) 14)}
;
extern TNimType NTI__ycbpMCRV6Cd2eBh3X9biEiw_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NvI37FoCN5uTD3k9bAqbGMA_5 = {((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_4),
((NI) 133),
((NI) 14)}
;
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__NvI37FoCN5uTD3k9bAqbGMA_6 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x03,
0xfe, 0xff, 0xff, 0x87, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_8, "int", 3);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_9, "uint", 4);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_10, "cint", 4);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_11, "cuint", 5);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_12, "clong", 5);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_13, "cstring", 7);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_14, "string", 6);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_15, "char", 4);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_16, "byte", 4);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_17, "bool", 4);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_18, "openArray", 9);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_19, "seq", 3);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_20, "array", 5);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_21, "void", 4);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_22, "pointer", 7);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_23, "float", 5);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_24, "csize", 5);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_25, "csize_t", 7);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_26, "cdouble", 7);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_27, "cchar", 5);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_28, "cschar", 6);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_29, "cshort", 6);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_30, "cu", 2);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_31, "nil", 3);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_32, "typedesc", 8);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_33, "auto", 4);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_34, "any", 3);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_35, "range", 5);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_36, "openarray", 9);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_37, "varargs", 7);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_38, "set", 3);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_39, "cfloat", 6);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_40, "ref", 3);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_41, "ptr", 3);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_42, "untyped", 7);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_43, "typed", 5);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_44, "static", 6);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_45, "sink", 4);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_46, "lent", 4);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_47, "type", 4);
STRING_LITERAL(TM__NvI37FoCN5uTD3k9bAqbGMA_48, "owned", 5);
static NIM_CONST tyArray__MsV5BSbGWsT9bkb3LKumkBA TM__NvI37FoCN5uTD3k9bAqbGMA_7 = {((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_8),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_9),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_10),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_11),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_12),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_13),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_14),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_15),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_16),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_17),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_18),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_19),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_20),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_21),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_22),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_23),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_24),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_25),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_26),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_27),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_28),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_29),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_30),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_31),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_32),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_33),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_34),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_35),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_36),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_37),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_38),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_39),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_40),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_41),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_42),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_43),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_44),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_45),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_46),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_47),
((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_48)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NvI37FoCN5uTD3k9bAqbGMA_49 = {((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_4),
((NI) 93),
((NI) 14)}
;

/* section: NIM_merge_PROCS */
N_LIB_PRIVATE N_NIMCALL(NI, identLen__cr8f4oiC7y4wZkhdloxc7w)(NimStringDesc* line, NI start) {
	NI result;
	result = (NI)0;
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = ((NI)(start + result) < (line ? line->Sup.len : 0));
			if (!(T3_)) goto LA4_;
			T3_ = (((NU8)(line->data[(NI)(start + result)])) >= ((NU8)(97)) && ((NU8)(line->data[(NI)(start + result)])) <= ((NU8)(122)) || ((NU8)(line->data[(NI)(start + result)])) >= ((NU8)(65)) && ((NU8)(line->data[(NI)(start + result)])) <= ((NU8)(90)) || ((NU8)(line->data[(NI)(start + result)])) >= ((NU8)(48)) && ((NU8)(line->data[(NI)(start + result)])) <= ((NU8)(57)) || ((NU8)(line->data[(NI)(start + result)])) >= ((NU8)(128)) && ((NU8)(line->data[(NI)(start + result)])) <= ((NU8)(255)) || ((NU8)(line->data[(NI)(start + result)])) == ((NU8)(95)));
			LA4_: ;
			if (!T3_) goto LA2;
			result += ((NI) 1);
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, substrEq__rlI4fq2VQx4GgCkgwctENA)(NimStringDesc* s, NI pos, NI last, NimStringDesc* substr) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	result = NIM_TRUE;
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (substr ? substr->Sup.len : 0);
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = (last < (NI)(pos + i));
					if (T6_) goto LA7_;
					T6_ = !(((NU8)(s->data[(NI)(pos + i)]) == (NU8)(substr->data[i])));
					LA7_: ;
					if (!T6_) goto LA8_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringDesc*, X5BX5D___FPvLvuwqfYMFkcbGfPM8QQsystem)(NimStringDesc* s, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA x) {
	NimStringDesc* result;
	NI a;
	NI L;
	result = (NimStringDesc*)0;
	a = x.a;
	L = (NI)((NI)(x.b - a) + ((NI) 1));
	result = mnewString(((NI) (L)));
	{
		NI i;
		NI i_2;
		i = (NI)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < L)) goto LA3;
				i = i_2;
				result->data[i] = s->data[(NI)(i + a)];
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
static N_INLINE(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA, dotdot___BokNSDrKN1xmV1nA01G9brAsystem)(NI a, NI b) {
	tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	nimZeroMem((void*)(&result), sizeof(tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA));
	result.a = a;
	result.b = b;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, differ__fOl7C7KzPONPqjNV4s3alQ)(NimStringDesc* line, NI a, NI b, NimStringDesc* x) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = ((NimStringDesc*) NIM_NIL);
	{
		NIM_BOOL T3_;
		NimStringDesc* y;
		tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = substrEq__rlI4fq2VQx4GgCkgwctENA(line, a, b, x);
		if (!!(T3_)) goto LA4_;
		T6_ = dotdot___BokNSDrKN1xmV1nA01G9brAsystem(a, b);
		y = X5BX5D___FPvLvuwqfYMFkcbGfPM8QQsystem(line, T6_);
		{
			NI T9_;
			T9_ = (NI)0;
			T9_ = nsuCmpIgnoreStyle(y, x);
			if (!(T9_ == ((NI) 0))) goto LA10_;
			result = copyString(y);
		}
		LA10_: ;
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, differs__cUWYbX789ccOdpBttqaEifQ)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* newName) {
	NimStringDesc* result;
	NimStringDesc* line;
	NI first;
	NI last;
	NI T19_;
{	result = (NimStringDesc*)0;
	line = sourceLine__b49bYNvmBdG6RP9cHaZGFhvQ(conf, info);
	first = ((((NI) (info.col)) <= (line ? line->Sup.len : 0)) ? ((NI) (info.col)) : (line ? line->Sup.len : 0));
	{
		if (!(first < ((NI) 0))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		while (1) {
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = (((NI) 0) < first);
			if (!(T7_)) goto LA8_;
			T7_ = (((NU8)(line->data[(NI)(first - ((NI) 1))])) >= ((NU8)(97)) && ((NU8)(line->data[(NI)(first - ((NI) 1))])) <= ((NU8)(122)) || ((NU8)(line->data[(NI)(first - ((NI) 1))])) >= ((NU8)(65)) && ((NU8)(line->data[(NI)(first - ((NI) 1))])) <= ((NU8)(90)) || ((NU8)(line->data[(NI)(first - ((NI) 1))])) >= ((NU8)(48)) && ((NU8)(line->data[(NI)(first - ((NI) 1))])) <= ((NU8)(57)) || ((NU8)(line->data[(NI)(first - ((NI) 1))])) >= ((NU8)(128)) && ((NU8)(line->data[(NI)(first - ((NI) 1))])) <= ((NU8)(255)) || ((NU8)(line->data[(NI)(first - ((NI) 1))])) == ((NU8)(95)));
			LA8_: ;
			if (!T7_) goto LA6;
			first -= ((NI) 1);
		} LA6: ;
	}
	{
		if (!(first < ((NI) 0))) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	{
		NIM_BOOL T15_;
		T15_ = (NIM_BOOL)0;
		T15_ = ((NI)(first + ((NI) 1)) < (line ? line->Sup.len : 0));
		if (!(T15_)) goto LA16_;
		T15_ = ((NU8)(line->data[first]) == (NU8)(96));
		LA16_: ;
		if (!T15_) goto LA17_;
		first += ((NI) 1);
	}
	LA17_: ;
	T19_ = (NI)0;
	T19_ = identLen__cr8f4oiC7y4wZkhdloxc7w(line, first);
	last = (NI)((NI)(first + T19_) - ((NI) 1));
	result = differ__fOl7C7KzPONPqjNV4s3alQ(line, first, last, newName);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, styleCheckUse__k3cqh606mJPYNzLXdtZjIg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NimStringDesc* newName;
	NimStringDesc* oldName;
{	{
		if (!(((NI) (info.fileIndex)) < ((NI) 0))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		NIM_BOOL T8_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 5));
		if (T8_) goto LA9_;
		T8_ = !((((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(97)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(122)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(65)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(90)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(57)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(128)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(255)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) == ((NU8)(95))));
		LA9_: ;
		T7_ = T8_;
		if (T7_) goto LA10_;
		T7_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 33))&63U)))!=0);
		LA10_: ;
		if (!T7_) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	newName = (*(*s).name).s;
	oldName = differs__cUWYbX789ccOdpBttqaEifQ(conf, info, newName);
	{
		NimStringDesc* mX60gensym23_;
		tyArray__Re75IspeoxXy2oCZHwcRrA T17_;
		tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msgX60gensym23_;
		if (!(((NI) 0) < (oldName ? oldName->Sup.len : 0))) goto LA15_;
		nimZeroMem((void*)T17_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T17_[0] = copyString(newName);
		T17_[1] = copyString(oldName);
		mX60gensym23_ = nsuFormatOpenArray(((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_2), T17_, 2);
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 15))&63U)))!=0)) goto LA20_;
			msgX60gensym23_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10);
		}
		goto LA18_;
		LA20_: ;
		{
			msgX60gensym23_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 69);
		}
		LA18_: ;
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, msgX60gensym23_, mX60gensym23_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__NvI37FoCN5uTD3k9bAqbGMA_3, NIM_FALSE);
	}
	LA15_: ;
	}BeforeRet_: ;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkPragmaUse__no49bEWZLCgyYgYqiaocHSg)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TSpecialWord__ycbpMCRV6Cd2eBh3X9biEiw w, NimStringDesc* pragmaName) {
	NimStringDesc* wanted;
	wanted = reprEnum((NI)w, (&NTI__ycbpMCRV6Cd2eBh3X9biEiw_));
	{
		NimStringDesc* mX60gensym27_;
		tyArray__Re75IspeoxXy2oCZHwcRrA T5_;
		tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msgX60gensym27_;
		if (!!(eqStrings(pragmaName, wanted))) goto LA3_;
		nimZeroMem((void*)T5_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T5_[0] = copyString(wanted);
		T5_[1] = copyString(pragmaName);
		mX60gensym27_ = nsuFormatOpenArray(((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_2), T5_, 2);
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 15))&63U)))!=0)) goto LA8_;
			msgX60gensym27_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10);
		}
		goto LA6_;
		LA8_: ;
		{
			msgX60gensym27_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 69);
		}
		LA6_: ;
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, msgX60gensym27_, mX60gensym27_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__NvI37FoCN5uTD3k9bAqbGMA_5, NIM_FALSE);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqtilde___IUBpCwAnZj8k6Q9b3zNUjzg)(NimStringDesc* s, NimStringDesc** a, NI aLen_0) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NimStringDesc** x;
		NI i;
		x = (NimStringDesc**)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < aLen_0)) goto LA3;
				x = (&a[i]);
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = nsuStartsWith(s, (*x));
					if (!T6_) goto LA7_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
				LA7_: ;
				i += ((NI) 1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__31wM5Ui9c8jnrQ5QD4oPxOQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NI result;
{	result = (NI)0;
	result = ((NI) 0);
	{
		NIM_CHAR i;
		NI i_2;
		i = (NIM_CHAR)0;
		i_2 = ((NI) 0);
		{
			while (1) {
				if (!(i_2 < aLen_0)) goto LA3;
				i = a[i_2];
				{
					if (!((NU8)(i) == (NU8)(item))) goto LA6_;
					goto BeforeRet_;
				}
				LA6_: ;
				result += ((NI) 1);
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
	result = ((NI) -1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem)(NIM_CHAR* a, NI aLen_0, NIM_CHAR item) {
	NIM_BOOL result;
	NI T1_;
{	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = find__31wM5Ui9c8jnrQ5QD4oPxOQsystem(a, aLen_0, item);
	result = (((NI) 0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, beautifyName__9a3XujgxAEMrMsWlLydkJvg)(NimStringDesc* s, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k) {
	NimStringDesc* result;
	NIM_BOOL allUpper;
	NI i;
{	result = (NimStringDesc*)0;
	allUpper = allCharsInSet__dubrHoRt3C9a0HlJjsxM5ig(s, TM__NvI37FoCN5uTD3k9bAqbGMA_6);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = allUpper;
		if (!(T3_)) goto LA4_;
		T3_ = ((1049728 &((NU32)1<<((NU)(k)&31U)))!=0);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = copyString(s);
		goto BeforeRet_;
	}
	LA5_: ;
	result = rawNewString(((NI) ((s ? s->Sup.len : 0))));
	i = ((NI) 0);
	switch (k) {
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 7):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 4):
	{
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = eqtilde___IUBpCwAnZj8k6Q9b3zNUjzg(s, TM__NvI37FoCN5uTD3k9bAqbGMA_7, 41);
			if (!T10_) goto LA11_;
			result = addChar(result, s->data[i]);
		}
		goto LA8_;
		LA11_: ;
		{
			NIM_CHAR T14_;
			T14_ = (NIM_CHAR)0;
			T14_ = nsuToUpperAsciiChar(s->data[i]);
			result = addChar(result, T14_);
		}
		LA8_: ;
	}
	break;
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 10):
	case ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 20):
	{
		result = addChar(result, s->data[((NI) 0)]);
	}
	break;
	default:
	{
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = ((s ? s->Sup.len : 0) == ((NI) 1));
			if (!(T19_)) goto LA20_;
			T19_ = ((NU8)(s->data[((NI) 0)]) == (NU8)(76));
			LA20_: ;
			if (!T19_) goto LA21_;
			result = addChar(result, 76);
		}
		goto LA17_;
		LA21_: ;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = contains__Pa9a8m0kZYH6LC8N1EcZJdQsystem(s->data, (s ? s->Sup.len : 0), 95);
			if (!T24_) goto LA25_;
			result = addChar(result, s->data[i]);
		}
		goto LA17_;
		LA25_: ;
		{
			NIM_CHAR T28_;
			T28_ = (NIM_CHAR)0;
			T28_ = nsuToLowerAsciiChar(s->data[((NI) 0)]);
			result = addChar(result, T28_);
		}
		LA17_: ;
	}
	break;
	}
	i += ((NI) 1);
	{
		while (1) {
			if (!(i < (s ? s->Sup.len : 0))) goto LA30;
			{
				if (!((NU8)(s->data[i]) == (NU8)(95))) goto LA33_;
				{
					NIM_BOOL T37_;
					T37_ = (NIM_BOOL)0;
					T37_ = (((NI) 0) < i);
					if (!(T37_)) goto LA38_;
					T37_ = (((NU8)(s->data[(NI)(i - ((NI) 1))])) >= ((NU8)(65)) && ((NU8)(s->data[(NI)(i - ((NI) 1))])) <= ((NU8)(90)));
					LA38_: ;
					if (!T37_) goto LA39_;
					result = addChar(result, 95);
					i += ((NI) 1);
					result = addChar(result, s->data[i]);
				}
				goto LA35_;
				LA39_: ;
				{
					NIM_CHAR T42_;
					i += ((NI) 1);
					T42_ = (NIM_CHAR)0;
					T42_ = nsuToUpperAsciiChar(s->data[i]);
					result = addChar(result, T42_);
				}
				LA35_: ;
			}
			goto LA31_;
			LA33_: ;
			{
				NIM_CHAR T46_;
				if (!allUpper) goto LA44_;
				T46_ = (NIM_CHAR)0;
				T46_ = nsuToLowerAsciiChar(s->data[i]);
				result = addChar(result, T46_);
			}
			goto LA31_;
			LA44_: ;
			{
				result = addChar(result, s->data[i]);
			}
			LA31_: ;
			i += ((NI) 1);
		} LA30: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nep1CheckDefImpl__6AhukMkhQSFShlHi9bHQBWw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw k) {
	NimStringDesc* beau;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((2080 &((NU32)1<<((NU)(k)&31U)))!=0);
		if (T3_) goto LA4_;
		T3_ = !((((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(97)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(122)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(65)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(90)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(48)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(57)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) >= ((NU8)(128)) && ((NU8)((*(*s).name).s->data[((NI) 0)])) <= ((NU8)(255)) || ((NU8)((*(*s).name).s->data[((NI) 0)])) == ((NU8)(95))));
		LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
	LA5_: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = ((144 &((NU32)1<<((NU)(k)&31U)))!=0);
		if (!(T9_)) goto LA10_;
		T9_ = (((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 33))&63U)))!=0);
		LA10_: ;
		if (!T9_) goto LA11_;
		goto BeforeRet_;
	}
	LA11_: ;
	{
		NIM_BOOL T15_;
		T15_ = (NIM_BOOL)0;
		T15_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T15_)) goto LA16_;
		T15_ = ((*(*s).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 8));
		LA16_: ;
		if (!T15_) goto LA17_;
		goto BeforeRet_;
	}
	LA17_: ;
	{
		if (!!(((192 & (*s).flags) == 0))) goto LA21_;
		goto BeforeRet_;
	}
	LA21_: ;
	{
		if (!!((((*s).options &((NU32)1<<((NU)(((tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg) 10))&31U)))!=0))) goto LA25_;
		goto BeforeRet_;
	}
	LA25_: ;
	beau = beautifyName__9a3XujgxAEMrMsWlLydkJvg((*(*s).name).s, k);
	{
		NimStringDesc* mX60gensym15_;
		tyArray__Re75IspeoxXy2oCZHwcRrA T31_;
		tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msgX60gensym15_;
		if (!!(eqStrings((*(*s).name).s, beau))) goto LA29_;
		nimZeroMem((void*)T31_, sizeof(tyArray__Re75IspeoxXy2oCZHwcRrA));
		T31_[0] = copyString(beau);
		T31_[1] = copyString((*(*s).name).s);
		mX60gensym15_ = nsuFormatOpenArray(((NimStringDesc*) &TM__NvI37FoCN5uTD3k9bAqbGMA_2), T31_, 2);
		{
			if (!(((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 15))&63U)))!=0)) goto LA34_;
			msgX60gensym15_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10);
		}
		goto LA32_;
		LA34_: ;
		{
			msgX60gensym15_ = ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 69);
		}
		LA32_: ;
		liMessage__Q6JNH4uRwLyZrj0dJakHew(conf, info, msgX60gensym15_, mX60gensym15_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__NvI37FoCN5uTD3k9bAqbGMA_49, NIM_FALSE);
	}
	LA29_: ;
	}BeforeRet_: ;
}
